/**
 *
 * Copyright (C) 2013, 2014 Olivier Berthier
 *                    http://www.xunil.fr
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 **/

/**
 * \file delaunay.h
 * \brief GA Triangulation Delaunay
 * \author Luis Felipe Restrepo Botero, Olivier Berthier
 * \date décembre 2013
 *
 */
#ifndef DELAUNAY_H
#define DELAUNAY_H

#include "commun.h"
#include "simplex.h"
#include "vertex.h"



/*!
 * \fn listSimplex* delaunay(vertex* L,unsigned int iterations)
 * \param L liste de vertex
 * \param faces Nombre de triangles max
 * \param iterations Nombre d'itérations max
 * \param seuil Hauteur maximal des points dans les triangles par rapport à l'échelle de Z
 * \param Activer l'optimisation : arrêt à la hauteur 0
 * \return Liste de triangles de Delaunay
 * \brief Execute la triangulatisation de Delaunay sur la liste de vertex L.
 */
listSimplex* delaunay(vertex* L, unsigned long faces,unsigned long iterations, double seuil,int optimise);

/*!
 * \fn void delaunay_it(listSimplex* queue)
 * \param queue
 * \brief Procédure de debugage, exécute une itération de Delaunay
 */
void delaunay_it(listSimplex* queue);

/*!
 * \fn int splitQuad(vertex* L, listSimplex* l)
 * \param L Liste de vertex
 * \param l Liste de simplex
 * \return int
 * \brief Fonction permetant d'initialiser deux simplex à partir des 4 premiers vertex d'une liste.
 */
int splitQuad(vertex* L, listSimplex* l);

/*!
 * \fn int checkDelaunayFull(listSimplex* l, int v)
 * \param l Liste de simplex
 * \param m version du test : 1 = InCircle, 2 = cercle circonscrit
 * \param v Verbose
 * \return 1 si pas d'erreur
 * \brief Fonction permettant de tester la triangulation de delaunay
 */
int checkDelaunayFull(listSimplex* l, int m, int v);

#endif //DELAUNAY_H
